==> 3050-PostSoftwareAssuranceTool-1.1.0-1.zip: MemberJoinDlg.h <==
#if !defined(AFX_MEMBERJOINDLG_H__3065C76B_1F33_4FD8_8006_3D13E590C9FF__INCLUDED_)
#define AFX_MEMBERJOINDLG_H__3065C76B_1F33_4FD8_8006_3D13E590C9FF__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// MemberJoinDlg.h : header file
//

/////////////////////////////////////////////////////////////////////////////
// CMemberJoinDlg dialog

class CMemberJoinDlg : public CDialog
{
// Construction
public:
	CMemberJoinDlg(CWnd* pParent = NULL);   // standard constructor
	void DrawBackground ( CDC* pDC );
	void SetWindowPosition ( CPoint ptPosition );

// Dialog Data
//	enum { IDD = IDD_MEMBER_JOIN_DIALOG 246 };
	CBitmap			m_bmBackground;
	CPoint			m_ptPosition;
	//{{AFX_DATA(CMemberJoinDlg)
	enum { IDD = 246 };
	CEdit	m_edtPass2;
	CEdit	m_edtMail;
	CEdit	m_edtPass1;
	CEdit	m_edtId;
	YButton	m_btnJoin;
	YButton	m_btnCancel;
	//}}AFX_DATA


// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CMemberJoinDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
protected:

	// Generated message map functions
	//{{AFX_MSG(CMemberJoinDlg)
	afx_msg void OnButtonCancel();
	afx_msg void OnButtonJoin();
	virtual BOOL OnInitDialog();
	afx_msg void OnPaint();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_MEMBERJOINDLG_H__3065C76B_1F33_4FD8_8006_3D13E590C9FF__INCLUDED_)

==> 3050-PostSoftwareAssuranceTool-1.2.2-1.zip: MemberJoinDlg.h <==
#if !defined(AFX_MEMBERJOINDLG_H__3065C76B_1F33_4FD8_8006_3D13E590C9FF__INCLUDED_)
#define AFX_MEMBERJOINDLG_H__3065C76B_1F33_4FD8_8006_3D13E590C9FF__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// MemberJoinDlg.h : header file
//

/////////////////////////////////////////////////////////////////////////////
// CMemberJoinDlg dialog

class CMemberJoinDlg : public CDialog
{
// Construction
public:
	CMemberJoinDlg(CWnd* pParent = NULL);   // standard constructor
	void DrawBackground ( CDC* pDC );
	void SetWindowPosition ( CPoint ptPosition );
	void SetWnd(HWND hwnd);
	void SetSocket ( CClientSocket* pClientSocket );
	void GiveJoinMemberAck ( int nResult );

// Dialog Data
//	enum { IDD = IDD_MEMBER_JOIN_DIALOG 246 };
	BOOL			m_bFirst; 
	HWND			m_pHwnd;
	CBitmap			m_bmBackground;
	CPoint			m_ptPosition;
	CClientSocket*	m_pSocket;
	KJoinMemberPacket m_Packet;
	//{{AFX_DATA(CMemberJoinDlg)
	enum { IDD = 246 };
	CEdit	m_edtPass2;
	CEdit	m_edtMail;
	CEdit	m_edtPass1;
	CEdit	m_edtId;
	YButton	m_btnJoin;
	YButton	m_btnCancel;
	CString	m_strPass1;
	CString	m_strPass2;
	CString	m_strId;
	CString	m_strMail;
	//}}AFX_DATA


// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CMemberJoinDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
protected:

	// Generated message map functions
	//{{AFX_MSG(CMemberJoinDlg)
	afx_msg void OnButtonCancel();
	afx_msg void OnButtonJoin();
	virtual BOOL OnInitDialog();
	afx_msg void OnPaint();
	afx_msg void OnTimer(UINT nIDEvent);
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_MEMBERJOINDLG_H__3065C76B_1F33_4FD8_8006_3D13E590C9FF__INCLUDED_)
